<?php
$page_title = "APIシグネチャ設定";
include_once('template/base_head.php');
?>
			<!-- サイドバー -->
			<aside id="colLeft">
				<h1><a href=""><img src="img/logo.png" alt="iWallet"></a></h1>
				<div class="aside-heading">
					&nbsp;
				</div>
				&nbsp;
			</aside>
			<!-- /サイドバー -->
			<!-- メインカラム -->
			<div id="colMain">
				<div class="mainIn">
<?php include_once('template/base_nav.php'); ?>
					<article>
						<div class="article-heading">
							<h2><?php echo $page_title; ?></h2>
						</div>
						<?php $this -> echoMessage(); ?>
						<form id="acForm" action="" method="post">
							<table class="table col bdr default odd w60p fontXS m_auto mb20">
								<colgroup>
									<col class="w40p">
									<col class="w60p">
								</colgroup>
								<tr>
									<th>口座番号</th>
									<td>
										<?php $this -> echoUserAccount(); ?>
									</td>
								</tr>
								<tr>
									<th>氏名</th>
									<td>
										<?php $this -> echoLastName(); ?> <?php $this -> echoFirstName(); ?>
									</td>
								</tr>
								<tr>
									<th>APIユーザ名</th>
									<td>
										<input type="text" id="user_name" name="user_name" value="<?php $this -> echoUserName(); ?>" class="w30p">
									</td>
								</tr>
								<tr>
									<th>APIパスワード</th>
									<td>
										<input type="text" id="password" name="password" value="<?php $this -> echoPassword(); ?>" class="w30p">
									</td>
								</tr>
								<tr>
									<th>IPアドレス</th>
									<td>
										<textarea id="ip_address" name="ip_address" rows="10" cols="50"><?php $this -> echoIpAddress(); ?></textarea>
									</td>
								</tr>
								<tr>
									<th>ドメイン名</th>
									<td>
										<textarea id="domain_name" name="domain_name" rows="10" cols="50"><?php $this -> echoDomainName(); ?></textarea>
									</td>
								</tr>
								<tr>
									<th>確認設定</th>
									<td>
										<?php $this -> echoWhitelistSettingsCheckboxes(); ?>
									</td>
								</tr>
							</table>

							<input type="hidden" value="action" id="type" name="type" />
							<input type="hidden" value="<?php $this -> echoUserAccount(); ?>" id="user_account" name="user_account" />
							<input type="hidden" value="<?php $this -> echoAId(); ?>" id="a_id" name="a_id" />
							
							<!-- Language Transition Data (Anton) 04/23/2016 -->
							<input class="lang-trans-data" type="hidden" id="lang_data_action" value="/en/api_signature"/>
							<input class="lang-trans-data" type="hidden" id="lang_data_form" value="#acForm"/>
							<input class="lang-trans-data" type="hidden" id="lang_data_type" value="edit"/>
							<!-- /Language Transition Data -->
						</form>
						<p class="calign">
							<a href="" class="btn bg-default">&laquo; 戻る</a>&emsp;
							<input type="button" id="btnSave" value="保存する" class="btn bg-grad px80 hi25">&emsp;
							<input type="button" id="btnDelete" value="削除" class="btn bg-grad px80 hi25">
						</p>
						<div class="article-bottom">
						</div>
					</article>
				</div>
			</div>
			<!-- /メインカラム -->
		</div>
<?php include_once('template/base_foot.php'); ?>
	</div>

	<script src="js/api_signature.js"></script>
</body>
</html>
